.. _index:

#########
Eiffellib
#########

Eiffellib is a python library for subscribing to and publishing Eiffel events to a message-broker.

Contents
========

.. toctree::
   :maxdepth: 2

   Getting Started <readme>
   Examples <examples>

   License <license>
   Authors <authors>
   Contributing <contributing>
   Code of conduct <code_of_conduct>
   Changelog <changelog>
   Module Reference <api/modules>
